#
# spec file for package usb_modeswitch
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define source_name	usb-modeswitch
%define date		20150627
%define _udevdir %(pkg-config --variable=udevdir udev)
Name:           usb_modeswitch
Version:        2.2.5
Release:        6.2
Summary:        A mode switching tool for controlling multiple-device USB gear
License:        GPL-2.0+
Group:          Hardware/Mobile
Url:            http://www.draisberghof.de/usb_modeswitch
Source0:        http://www.draisberghof.de/usb_modeswitch/%{source_name}-%{version}.tar.bz2
Source1:        http://www.draisberghof.de/usb_modeswitch/%{source_name}-data-%{date}.tar.bz2
Source2:        http://www.draisberghof.de/usb_modeswitch/device_reference.txt
Patch1:         usb_modeswitch-fix_fsf_address.patch
BuildRequires:  fdupes
BuildRequires:  pkg-config
BuildRequires:  tcl
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(udev)
Requires:       tcl >= 8.4
Requires:       usb_modeswitch-data = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
USB_ModeSwitch is a mode switching tool for controlling "flip flop"
(multiple device) USB gear. It allows so-called "Zero-CD" devices that
show up as USB storage initially to be switched into their more useful
"application mode". This is most common for UMTS/3G wireless WAN
devices.

%package data
Summary:        Data Files for USB Modeswitch
Group:          Hardware/Mobile
Requires:       %{name} = %{version}
BuildArch:      noarch

%description data
Data files for usb_modeswitch package.

%prep
%setup -q -a1 -n %{source_name}-%{version}
%patch1

cp %{SOURCE2} .

%build
CFLAGS="%{optflags}" make

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags} UDEVDIR=%{buildroot}%{_udevdir}
cd %{source_name}-data-%{date}
make DESTDIR=%{buildroot} install %{?_smp_mflags} RULESDIR=%{buildroot}%{_udevdir}/rules.d

### TO REMOVE ONCE IN UPSTREAM DATA PACKAGE, FIX BNC 899013 ###

cat > %{buildroot}/%{_datadir}/usb_modeswitch/12d1:1583 <<EOF
# Vodafone W5101

TargetVendor=0x12d1
TargetProduct=0x1589

MessageContent="55534243123456780000000000000011062000000101000100000000000000"
EOF

cat > %{buildroot}/%{_datadir}/usb_modeswitch/12d1:1582 <<EOF
# Vodafone R215

TargetVendor=0x12d1
TargetProduct=0x1588

MessageContent="55534243123456780000000000000011062000000101000100000000000000"
EOF

### END SECTION TO REMOVE ###

%fdupes -s %{buildroot}

%files
%defattr(-,root,root,-)
%doc README COPYING device_reference.txt
%{_sbindir}/usb_modeswitch
%{_sbindir}/usb_modeswitch_dispatcher
%{_udevdir}/usb_modeswitch
%{_localstatedir}/lib/usb_modeswitch
%config %{_sysconfdir}/usb_modeswitch.conf
%{_mandir}/man1/usb_modeswitch.1.gz
%{_mandir}/man1/usb_modeswitch_dispatcher.1.gz

%files data
%defattr(-,root,root,-)
%{_datadir}/usb_modeswitch/
%{_udevdir}/rules.d/40-usb_modeswitch.rules

%changelog
* Fri Jul 24 2015 jweberhofer@weberhofer.at
- Removed unused usb_modeswitch-data.rpmlintrc
- Removed changelog from documentation
- Cleaned up specfile
- Update to version 2.2.5
  * Fixed bug in configuration check, possibly leading to segfault (thanks,
    Leonid Lisovskiy);
  * fixed Pantech commandline parameter evaluation (was not working at all);
  * added driver unbind step via sysfs in wrapper, getting rid of the
    USB subsystem complaint "interface 0 claimed by usb-storage while
    'usb_modeswitch' <does this and that>"
- Update to version 2.2.4
  * Fixed buggy check of USB configuration selection (possibly leading
    to segfault), tested with Alcatel X602D;
  * removed call to 'libusb_strerror'
    from libusb initialization - not available in earlier libusb1 versions
- Update to version 2.2.3
  * Fixed problem arising with systemd version 221 (220 untested), which
    affects starting the usb_modeswitch systemd unit from the sh script
    (reported by Archlinux users)
- Update to version 2.2.2, 2015/06/27
  * Added catch for libusb init error (thanks, Henrik Gustafsson);
  * removed global function result variable; added catch for USB configuration
    read error (both thanks to "otila");
  * fixed wrapper script where port search for symlinking modem port was
    broken ("/dev/gsmmodem");
  * changed PantechMode parameter to represent different targets;
  * added global config option to disable MBIM checking and setting
    alltogether (request from "kai");
  * changed udev sh script so that systemd processing takes precedence over
    upstart;
  * changed systemd template unit parameter to avoid escaping problems
- Update the data package to version 20150627
* Sat Apr 25 2015 coolo@suse.com
- use pkgconfig to detect udev install directory to avoid problems
  during bootstrap
* Wed Apr  8 2015 p.drouand@gmail.com
- Update to version 2.2.1
  * Fixed unreliable switching function for Cisco AM10
- Update the data package to version 20150115
- Update device_reference.txt
* Tue Mar 24 2015 cxiong@suse.com
- add usb_modeswitch-fix_fsf_address.patch
  * Update FSF address.
* Tue Nov  4 2014 andrea@opensuse.org
- removed patch obsolete huawei-timing.patch to fix boo#903753
* Mon Nov  3 2014 andrea@opensuse.org
- new upstream version 2.2.0
  * Introduction of parameter "HuaweiNewMode", wrapping the standard bulk
    message for all newer Huawei devices; support for generic fall-back
    config files, combined with OS switch (per vendor ID), implementation
    to use a specific switching command on Android for all Huawei devices
    (see README of data package for details); this change was suggested
    by Huawei
* Sat Oct 11 2014 andrea@opensuse.org
- fix for bnc #899013
* Thu Oct  2 2014 andrea@opensuse.org
- upgraded the data package to version 20140529
* Mon May 26 2014 tittiatcoke@gmail.com
- Update to 2.1.1
  * Code cleanup
  * Better usage of libusb1
  * -I flag meaning reversed, default is to skip SCSI inquiry
  * Experimental systemd and upstart integration
* Thu May 16 2013 mvyskocil@suse.com
- drop /bin/eject from dependencies, it is no longer called
- install device_reference.txt as %%doc
- use URL in all relevant Source tags
- drop obsoleted sections from spec
* Mon Dec  3 2012 p.drouand@gmail.com
- Update to 1.2.5:
  * Initial support for MBIM devices, use with data package >= 20121109;
    checking for these is the automatic default, new parameter NoMBIMCheck
    prevents the check per device in case of problems; new global option
    to set "delay_use" of usb-storage (as low values may prevent
    mode-switching);
  * fix for handling multi-configuration devices (thanks
    to Bjørn Mork for advice)
- Removed files:
  * add_alcatel_ot_x220d.patch: supported on upstream release
  * 1bbb:f017: supported on upstream release
- Adapt huawei-timing.patch for 1.2.5
* Wed Oct 17 2012 fcrozat@suse.com
- Fix build with new udev directory location
* Fri Sep 28 2012 gschlotter@suse.com
- huawei-timing.patch:
  * fixed timing issues with huawei devices (E173, ...)
    bnc#740354
* Fri Jul 20 2012 javier@opensuse.org
- Update data package to 20120531
- Add Alcatel OT-X220D support
* Sun Apr  1 2012 gankov@opensuse.org
- New data package 20120120
- Update to 1.2.3
- Add BuildRequires tcl
- Using fdupes
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Tue May 10 2011 andrea@opensuse.org
- New data package 20110227
- Update to 1.1.7:
  * Attention: paths for runtime files and database have changed!
  * fix for configuration setting race (thanks to Amit Mendapara);
  * discovered incompatibility between Tcl versions <= 8.3
    and >=8.4, so 8.4 is the minimum prerequisite now;
* Mon Jan 10 2011 dmueller@suse.de
- fix dependency
* Wed Jan  5 2011 bili@novell.com
- Update to 1.1.6 including:
  * Moved warm-boot driver binding to sh wrapper, was unreliable
    in 1.1.5;
  * initial device checking includes current "bConfigurationValue"
    now, should work with config setting for multiple devices;
  * made tcl script conform to limitations of "jimsh", the minimal
    tcl shell (hint from Barry Kauler);
  * fixes for "usbserial" fallback (driver binding for old systems);
  * in the C program, changed parameter "MessageDelay" (hitherto
    unused) to "ReleaseDelay", to be used in one device configuration
- Update database to 20101222 state.
* Tue Dec 14 2010 aj@suse.de
- Update to 1.1.5 including:
  * Added special control message for Kobil devices
  * try to get active configuration for interface class checking
  * fixed "0000" target product ID - again
  * new bash and tcl wrapper logic: the convenience functions for
    driver binding and symlinking will now start the tcl shell
    ONLY for known devices;
- Update database to 20101202 state.
* Mon Aug 23 2010 pth@suse.de
- Update to 1.1.4
  * The package should work at boot time now (cold and warm)
  * Product IDs of "0000" do exist but were not accepted, fixed
  * Response endpoint is now always detected
  * Wrapper script can now work with a packed collection of config
    files as well as with the plain folder of files
  * Wrapper fix for the symlink feature: handling of multiple interrupt
    ports was incomplete
  * Wrapper does not longer use a temporary file for the symlink feature
* Thu Jul  8 2010 andrea@opensuse.org
- New upstream version 1.1.3
  * Added delay option to separate multiple message
    transfers by millisecs
  * fixed (possibly dangerous) sloppy string handling
  * Added "clear_halt" for response endpoint
  * Small additions in Makefile (install with -D)
  * Changes in option handling (no more default config file!)
  * Symlink feature in wrapper can now cope with devices providing
    more than one interrupt port
  * Wrapper now ignores package manager leftovers in config folder
  * Replaced bash-specific syntax in wrapper
  * Changed ZTE skipping (if existing rules are found) to warning
- update data package to version 20100707
- spec file clean up (sources support 'make install')
* Tue May 18 2010 aj@suse.de
- Cleanup spec file.
* Tue May 11 2010 tuoma_mel@inbox.ru
- update to version 1.1.2
* Wed Jan 21 2009 seife@suse.de
- add dependency on /bin/eject (used in the udev rules)
* Wed Jan 21 2009 seife@suse.de
- update usb_modeswitch.conf (from 2009-01-13)
- add udev rules and a script to create them from the config file
* Mon Jan 12 2009 seife@suse.de
- update to version 0.9.6
  - special modes added for Sierra and Sony Ericsson, new devices
* Fri Nov  7 2008 seife@suse.de
- copied the package from home:perosb (Thanks!)
- added the latest config file from the home page
- install README
- use RPM_OPT_FLAGS
- enable useful debug info by not stripping the binary
